==> v0.0.16.zip: shellfu/test/include/harness.sh <==
#!/bin/bash
# ffoo test harness
# See LICENSE file for copyright and license details.

. test/include/common.sh

tf_has_files() {
    test -d "$1"               || return 1
    test -e "$1"/* &>/dev/null
    case $? in
        0) return 0 ;;
        1) return 1 ;;
        *) return 0 ;;
    esac
}

tf_enum_tests() {
    find test/scripts -maxdepth 1 -type f -perm /111 | cut -d/ -f3-
}

tf_run_tests() {
    local filter="${1:-.*}"
    local projdir=$PWD
    local artifact_dir="$projdir/test/artifacts"
    local tmpdir datadir results tname tes
    tf_think "# version: $(ffoom --version-full)"
    tf_think ""
    es=0
    for tname in $(tf_enum_tests);
    do
        tf_think "%%% $tname"
        tmpdir=$(mktemp -d)
        datadir="$projdir/test/data/$tname"
        stamp=$(date +artifacts-$tname-%Y%m%d-%H%M%S)
        pushd $tmpdir >/dev/null
            cp -r "$projdir/test/scripts/$tname" .
            tf_has_files "$datadir" && cp -r "$datadir/"* .
            TF_FILTER="$filter" TF_PROJDIR=$projdir TF_TNAME=$tname ./$tname
            tes=$?
            case $tes in
                0|2)        # ok    | bailout (skipped)
                    true
                    ;;
                *)          # fail  | error
                    mkdir -p "$artifact_dir/$stamp"
                    cp -r $tmpdir/* "$artifact_dir/$stamp"
                    ;;
            esac
            test $tes -gt $es && es=$tes
        popd >/dev/null
        rm -rf $tmpdir
        tf_think "%%% $tname ($tes)"
    done
    return $es
}

==> v0.4.1.zip: shellfu/test/include/harness.sh <==
#!/bin/bash
# ffoo test harness
# See LICENSE file for copyright and license details.

. test/include/common.sh

tf_has_files() {
    test -d "$1"               || return 1
    test -e "$1"/* &>/dev/null
    case $? in
        0) return 0 ;;
        1) return 1 ;;
        *) return 0 ;;
    esac
}

tf_enum_tests() {
    find test/scripts -maxdepth 1 -type f -perm /111 | cut -d/ -f3-
}

tf_run_tests() {
    local artifact_dir="$TF_PROJDIR/test/artifacts"
    local tmpdir datadir results tname tes
    tf_think "# version: $(ffoom --version-semver)"
    tf_think ""
    es=0
    for tname in $(tf_enum_tests | grep -e "$TF_FILTER_TEST");
    do
        tf_think "... $tname"
        tmpdir=$(mktemp -d)
        datadir="$TF_PROJDIR/test/data/$tname"
        stamp=$(date +artifacts-$tname-%Y%m%d-%H%M%S)
        pushd $tmpdir >/dev/null
            cp -r "$TF_PROJDIR/test/scripts/$tname" .
            tf_has_files "$datadir" && cp -r "$datadir/"* .
            TF_TNAME="$tname" ./$tname
            tes=$?
            case $tes in
                0|2)        # ok    | bailout (skipped)
                    true
                    ;;
                *)          # fail  | error
                    mkdir -p "$artifact_dir/$stamp"
                    cp -r $tmpdir/* "$artifact_dir/$stamp"
                    ;;
            esac
            test $tes -gt $es && es=$tes
        popd >/dev/null
        rm -rf $tmpdir
        if test $tes -eq 0;
        then
            tf_think "''' $tname ($tes)"
        else
            tf_warn "??? $tname ($tes)"
        fi
    done
    return $es
}
